@@ -2,12 +2,21 @@ use strict;
 use warnings;
 
 package BaseClass;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 use Moose;
 BEGIN { extends qw/MooseX::MethodAttributes::Inheritable/; }
 
+sub moo : Moo {}
+
 sub foo : Foo {}
 
+sub bar : Baz {}
+
+{
+    no warnings 'redefine';
+    sub moo : Moo {}
+}
+
 1;
